@@ -9,23 +9,24 @@
 #
 from __future__ import absolute_import, division, unicode_literals
 
+import base64
 import sys
 from datetime import date, datetime
 
 from jx_elasticsearch.rollover_index import RolloverIndex
 from jx_python import jx
 from mo_dots import coalesce, listwrap, set_default, to_data, is_data, is_sequence
-from mo_future import number_types, text, is_text, is_binary
+from mo_future import number_types, text, is_text, is_binary, binary_type
 from mo_json import datetime2unix, json2value, value2json
 from mo_kwargs import override
+from mo_math import randoms
+
 from mo_logs import Log, strings
 from mo_logs.exceptions import Except, suppress_exception
 from mo_logs.log_usingNothing import StructuredLogger
-from mo_math import randoms
 from mo_threads import Queue, THREAD_STOP, Thread, Till
 from mo_times import Duration, MINUTE
 from mo_times.dates import datetime2unix
-from pyLibrary.convert import bytes2base64
 
 MAX_BAD_COUNT = 5
 LOG_STRING_LENGTH = 2000
@@ -181,6 +182,12 @@ def _deep_json_to_string(value, depth):
         return strings.limit(value2json(value), LOG_STRING_LENGTH)
 
 
+def bytes2base64(value):
+    if isinstance(value, bytearray):
+        value = binary_type(value)
+    return base64.b64encode(value).decode("latin1")
+
+
 SCHEMA = {
     "settings": {"index.number_of_shards": 6, "index.number_of_replicas": 2},
     "mappings": {
